@@ -1,6 +1,6 @@
 package Treex::Block::Read::BaseReader;
 {
-  $Treex::Block::Read::BaseReader::VERSION = '0.07191';
+  $Treex::Block::Read::BaseReader::VERSION = '0.08051';
 }
 use Moose;
 use Treex::Core::Common;
@@ -10,7 +10,7 @@ use Treex::Core::Document;
 
 sub next_document {
     my ($self) = @_;
-    return log_fatal "method next_document must be overriden in " . ref($self);
+    return log_fatal "method next_document must be overridden in " . ref($self);
 }
 
 has selector => ( isa => 'Treex::Type::Selector', is => 'ro', default => q{} );
@@ -26,6 +26,7 @@ has from => (
     isa           => 'Treex::Core::Files',
     is            => 'ro',
     coerce        => 1,
+    required      => 1,
     handles       => [qw(current_filename file_number _set_file_number)],
     documentation => 'arrayref of filenames to be loaded, '
         . 'coerced from a space or comma separated list of filenames, '
@@ -99,7 +100,15 @@ sub new_document {
 
     $self->_set_doc_number( $self->doc_number + 1 );
 
-    my $document = Treex::Core::Document->new( \%args );
+    my $document;
+    if ( defined $load_from and $load_from =~ /\.streex/ ) {
+        $document = Treex::Core::Document->retrieve_storable($load_from);
+        $document->set_storable(1);
+    }
+    else {
+        $document = Treex::Core::Document->new( \%args );
+    }
+
     if ( defined $load_from && $load_from =~ /\.gz$/ ) {
         $document->set_compress(1);
     }
@@ -127,7 +136,7 @@ Treex::Block::Read::BaseReader - abstract ancestor for document readers
 
 =head1 VERSION
 
-version 0.07191
+version 0.08051
 
 =head1 DESCRIPTION
 
@@ -143,14 +152,17 @@ and you can use C<next_filename> and C<new_document> methods.
 
 =over
 
-=item from (required, if C<filelist> is not set)
+=item from (required)
 
 space or comma separated list of filenames, or C<-> for STDIN
-(If you use this method via API you can specify C<filenames> instead.)
 
-=item filelist (required, if C<from> is not set)
+An '@' directly in front of a file name causes this file to be interpreted as a file
+list, with one file name per line, e.g. '@filelist.txt' causes the reader to open
+'filelist.txt' and read a list of files from it. File lists may be arbitrarily 
+mixed with regular files in the parameter. 
 
-path to a file that contains a list of files to be read (one per line) 
+(If you use this method via API you can specify a string array reference or a
+L<Treex::Core::Files> object.)
 
 =item file_stem (optional)
 
@@ -159,11 +171,6 @@ This attribute will be saved to the same-named
 attribute in documents and it will be used in document writers
 to decide where to save the files.
 
-=item filenames (internal)
-
-array of filenames to be loaded,
-automatically initialized from the attribute C<from>
-
 =back
 
 =head1 METHODS
@@ -172,7 +179,7 @@ automatically initialized from the attribute C<from>
 
 =item next_document
 
-This method must be overriden in derived classes.
+This method must be overridden in derived classes.
 (The implementation in this class just issues fatal error.)
 
 =item next_filename
@@ -213,10 +220,10 @@ L<Treex::Block::Read::Text>
 
 =head1 AUTHOR
 
-Martin Popel
+Martin Popel <popel@ufal.mff.cuni.cz>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2011 by Institute of Formal and Applied Linguistics, Charles University in Prague
+Copyright © 2011-2012 by Institute of Formal and Applied Linguistics, Charles University in Prague
 
 This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
