@@ -1,6 +1,6 @@
 package Treex::Core::BundleZone;
 {
-  $Treex::Core::BundleZone::VERSION = '0.07191';
+  $Treex::Core::BundleZone::VERSION = '0.08051';
 }
 
 use Moose;
@@ -35,32 +35,42 @@ sub get_document {
 }
 
 sub create_atree {
-    my $self = shift;
-    return $self->create_tree('a');
+    my ($self,$params_rf) = @_;
+    return $self->create_tree('a',$params_rf);
 }
 
 sub create_ttree {
-    my $self = shift;
-    return $self->create_tree('t');
+    my ($self,$params_rf) = @_;
+    return $self->create_tree('t',$params_rf);
 }
 
 sub create_ntree {
-    my $self = shift;
-    return $self->create_tree('n');
+    my ($self,$params_rf) = @_;
+    return $self->create_tree('n',$params_rf);
 }
 
 sub create_ptree {
-    my $self = shift;
-    return $self->create_tree('p');
+    my ($self,$params_rf) = @_;
+    return $self->create_tree('p',$params_rf);
 }
 
 sub create_tree {
     my $self = shift;
-    my ($layer) = pos_validated_list(
+    my ($layer,$params_rf) = pos_validated_list(
         \@_,
         { isa => 'Treex::Type::Layer' },
+        { isa => 'Ref' },
     );
-    log_fatal("Zone already contains tree at $layer layer") if $self->has_tree($layer);
+
+    if ($self->has_tree($layer)) {
+        if (defined $params_rf and $params_rf->{overwrite}) {
+            $self->remove_tree($layer);
+        }
+        else {
+            log_fatal("Zone already contains tree at $layer layer");
+        }
+    }
+
     my $class = "Treex::Core::Node::" . uc($layer);
     my $tree_root = eval { $class->new( { _called_from_core_ => 1 } ) } or log_fatal $!;    #layer subclasses not available yet
 
@@ -200,10 +210,19 @@ sub copy {
     # Get the bundle the zone is in.
     my $bundle = $self->get_bundle();
     my $zone1 = $bundle->get_or_create_zone( $self->language(), $selector1 );
-    ### TO DO: copy other trees, too (currently only copies the a-tree)
-    my $aroot0 = $self->get_atree();
-    my $aroot1 = $zone1->create_atree();
-    $aroot0->copy_atree($aroot1);
+    ### TO DO: copy other trees, too (currently only copies a-tree and p-tree)
+    if($self->has_atree())
+    {
+        my $aroot0 = $self->get_atree();
+        my $aroot1 = $zone1->create_atree();
+        $aroot0->copy_atree($aroot1);
+    }
+    if($self->has_ptree())
+    {
+        my $proot0 = $self->get_ptree();
+        my $proot1 = $zone1->create_ptree();
+        $proot0->copy_ptree($proot1);
+    }
     return $zone1;
 }
 
@@ -221,7 +240,7 @@ Treex::Core::BundleZone - contains a sentence and its linguistic representations
 
 =head1 VERSION
 
-version 0.07191
+version 0.08051
 
 =head1 SYNOPSIS
 
