@@ -1,6 +1,6 @@
 package Treex::Core::TredView;
 {
-  $Treex::Core::TredView::VERSION = '0.07191';
+  $Treex::Core::TredView::VERSION = '0.08051';
 }
 
 # planned to be used from contrib.mac of tred's extensions
@@ -14,6 +14,9 @@ use Treex::Core::TredView::Vallex;
 use Treex::Core::Types;
 use List::Util qw(first);
 
+use Treex::Core::Config;
+$Treex::Core::Config::running_in_tred = 1;
+
 has 'grp'       => ( is => 'rw' );
 has 'pml_doc'   => ( is => 'rw' );
 has 'treex_doc' => ( is => 'rw' );
@@ -49,18 +52,18 @@ has fast_loading => (
 );
 
 has _displayed_nodes => (
-    is => 'rw',
-    isa => 'HashRef[Treex::Core::Node]',
+    is      => 'rw',
+    isa     => 'HashRef[Treex::Core::Node]',
     default => sub { {} }
 );
 has _ptb_index_map => (
-    is => 'rw',
-    isa => 'HashRef[Treex::Core::Node::P]',
+    is      => 'rw',
+    isa     => 'HashRef[Treex::Core::Node::P]',
     default => sub { {} }
 );
 has _ptb_coindex_map => (
-    is => 'rw',
-    isa => 'HashRef[Treex::Core::Node::P]',
+    is      => 'rw',
+    isa     => 'HashRef[Treex::Core::Node::P]',
     default => sub { {} }
 );
 
@@ -106,7 +109,7 @@ sub get_nodelist_hook {
                                              # results in Can't locate object method "get_all_zones" via package "Treex::PML::Node" at /ha/work/people/popel/tectomt/treex/lib/Treex/Core/TredView.pm line 22
 
     my $layout = $self->tree_layout->get_layout();
-    $self->{'_ptb_index_map'} = {};
+    $self->{'_ptb_index_map'}   = {};
     $self->{'_ptb_coindex_map'} = {};
     my %nodes;
 
@@ -117,8 +120,8 @@ sub get_nodelist_hook {
             @nodes = $self->_spread_nodes($tree);
             shift @nodes;
             foreach my $node (@nodes) {
-                $self->{'_ptb_index_map'}->{$node->{'index'}} = $node if defined $node->{'index'};
-                $self->{'_ptb_coindex_map'}->{$node->{'coindex'}} = $node if defined $node->{'coindex'};
+                $self->{'_ptb_index_map'}->{ $node->{'index'} }     = $node if defined $node->{'index'};
+                $self->{'_ptb_coindex_map'}->{ $node->{'coindex'} } = $node if defined $node->{'coindex'};
             }
         }
         elsif ( $tree->does('Treex::Core::Node::Ordered') ) {
@@ -203,12 +206,31 @@ sub get_nodelist_hook {
     return [ \@nodes, $currentNode ];
 }
 
+sub recompute_visualization {
+    my ( $self, $bundle ) = @_;
+    $self->precompute_tree_depths($bundle);
+    $self->precompute_tree_shifts($bundle);
+    $self->precompute_visualization($bundle);
+    return;
+}
+
 sub file_opened_hook {
     my ($self) = @_;
     my $pmldoc = $self->grp()->{FSFile};
 
     $self->pml_doc($pmldoc);
-    my $treex_doc = Treex::Core::Document->new( { pmldoc => $pmldoc } );
+
+    my $treex_doc;
+    if ( defined $pmldoc->[13]->{_treex_core_document} ) {    # if it comes from storable (i.e., already with moose)
+        $treex_doc = $pmldoc->[13]->{_treex_core_document};
+
+        # streex files do not have "wild_dump" filled, but we want to show this in ttred
+        $treex_doc->_serialize_all_wild();
+    }
+    else {
+        $treex_doc = Treex::Core::Document->new( { pmldoc => $pmldoc } );
+    }
+
     $self->treex_doc($treex_doc);
 
     # labels, styles and vallex must be created again for each file
@@ -265,9 +287,9 @@ sub value_line_doubleclick_hook {
         $found = 0;
         for ( my $col = 0; $col < scalar @$layout; $col++ ) {
             if ( defined $layout->[$col][$row] ) {
-                if ($layout->[$col][$row]->{'visible'}) {
+                if ( $layout->[$col][$row]->{'visible'} ) {
                     $ordering{ $layout->[$col][$row]->{'label'} } = $i++;
-                    $visible{$layout->[$col][$row]->{'label'}} = 1;
+                    $visible{ $layout->[$col][$row]->{'label'} }  = 1;
                 }
                 $found = 1;
             }
@@ -276,9 +298,9 @@ sub value_line_doubleclick_hook {
     }
     my @trees = sort {
         $ordering{ $self->tree_layout->get_tree_label($a) } <=> $ordering{ $self->tree_layout->get_tree_label($b) }
-    } grep {
-      exists $visible{ $self->tree_layout->get_tree_label($_) }
-    } $bundle->get_all_trees;
+        } grep {
+        exists $visible{ $self->tree_layout->get_tree_label($_) }
+        } $bundle->get_all_trees;
 
     for my $tree (@trees) {
         for my $node ( $tree->get_descendants ) {
@@ -392,7 +414,7 @@ sub precompute_visualization {
 }
 
 sub get_clickable_sentence_for_a_zone {
-    my ( $self, $zone ) = @_;
+    my ( $self, $zone, $alignment ) = @_;
     return if !$zone->has_atree();
     my %refs = ();
 
@@ -400,8 +422,16 @@ sub get_clickable_sentence_for_a_zone {
         for my $tnode ( $zone->get_ttree->get_descendants ) {
             for my $aux ( TredMacro::ListV( $tnode->attr('a/aux.rf') ) ) {
                 push @{ $refs{$aux} }, $tnode;
+                if ( exists $alignment->{ $tnode->get_attr('id') } ) {
+                    push @{ $refs{$aux} }, @{ $alignment->{ $tnode->get_attr('id') } };
+                }
+            }
+            if ( $tnode->attr('a/lex.rf') ) {
+                push @{ $refs{ $tnode->attr('a/lex.rf') } }, $tnode;
+                if ( exists $alignment->{ $tnode->get_attr('id') } ) {
+                    push @{ $refs{ $tnode->attr('a/lex.rf') } }, @{ $alignment->{ $tnode->get_attr('id') } };
+                }
             }
-            push @{ $refs{ $tnode->attr('a/lex.rf') } }, $tnode if $tnode->attr('a/lex.rf');
         }
     }
 
@@ -409,6 +439,9 @@ sub get_clickable_sentence_for_a_zone {
     for my $anode (@anodes) {
         my $id = $anode->id;
         push @{ $refs{$id} }, $anode;
+        if ( exists $alignment->{$id} ) {
+            push @{ $refs{$id} }, @{ $alignment->{$id} };
+        }
         if ( $anode->attr('p_terminal.rf') ) {
             my $pnode = $self->treex_doc->get_node_by_id( $anode->attr('p_terminal.rf') );
             push @{ $refs{$id} }, $pnode;
@@ -438,10 +471,27 @@ sub get_clickable_sentence_for_a_zone {
 sub precompute_value_line {
     my ( $self, $bundle ) = @_;
 
+    my %alignment = ();
+    foreach my $zone ( $bundle->get_all_zones() ) {
+        foreach my $layer (@layers) {
+            if ( $zone->has_tree($layer) ) {
+                my $root = $zone->get_tree($layer);
+                foreach my $node ( $root, $root->get_descendants ) {
+                    if ( exists $node->{'alignment'} ) {
+                        foreach my $ref ( @{ $node->get_attr('alignment') } ) {
+                            push @{ $alignment{ $node->{id} } }, $self->treex_doc->get_node_by_id( $ref->{'counterpart.rf'} );
+                            push @{ $alignment{ $ref->{'counterpart.rf'} } }, $node;
+                        }
+                    }
+                }
+            }
+        }
+    }
+
     my @out = ();
     foreach my $zone ( $bundle->get_all_zones() ) {
         push @out, ( [ '[' . $zone->get_label . ']', 'label' ], [ ' ', 'space' ] );
-        if ( my $sentence = $self->get_clickable_sentence_for_a_zone($zone) ) {
+        if ( my $sentence = $self->get_clickable_sentence_for_a_zone( $zone, \%alignment ) ) {
             push @out, @$sentence;
         }
         elsif ( defined $zone->sentence ) {
@@ -503,7 +553,7 @@ sub tnode_hint {
 
     if ( ref $node->get_attr('gram') ) {
         foreach my $gram ( keys %{ $node->get_attr('gram') } ) {
-            push @lines, "gram/$gram : " . $node->get_attr( 'gram/' . $gram );
+            push @lines, "gram/$gram : " . ( $node->get_attr( 'gram/' . $gram ) || '' );
         }
     }
 
@@ -526,7 +576,7 @@ sub pnode_hint {
     my ( $self, $node ) = @_;
     my @lines = ();
 
-    if ($node->is_terminal) {
+    if ( $node->is_terminal ) {
         push @lines, map { "$_: " . ( defined $node->{$_} ? $node->{$_} : '' ) } qw(lemma tag form);
     }
     else {
@@ -559,25 +609,27 @@ sub node_style_hook {
     }
 
     # P-layer indexes and coindexes
-    if ($node->get_layer eq 'p') {
+    if ( $node->get_layer eq 'p' ) {
         my $coindex;
-        if ($node->attr('form') and $node->attr('form') =~ m/-(\d+)$/) {
+        if ( $node->attr('form') and $node->attr('form') =~ m/-(\d+)$/ ) {
             $coindex = $1;
-        } elsif ($node->attr('coindex')) {
+        }
+        elsif ( $node->attr('coindex') ) {
             $coindex = $node->attr('coindex');
         }
 
         if ($coindex) {
             my $target_node;
-            if (exists $self->{'_ptb_index_map'}->{$coindex}) {
-              $target_node = $self->{'_ptb_index_map'}->{$coindex};
-            } elsif ($node->is_terminal and exists $self->{'_ptb_coindex_map'}->{$coindex}) {
-              $target_node = $self->{'_ptb_coindex_map'}->{$coindex};
+            if ( exists $self->{'_ptb_index_map'}->{$coindex} ) {
+                $target_node = $self->{'_ptb_index_map'}->{$coindex};
+            }
+            elsif ( $node->is_terminal and exists $self->{'_ptb_coindex_map'}->{$coindex} ) {
+                $target_node = $self->{'_ptb_coindex_map'}->{$coindex};
             }
 
             if ($target_node) {
-              push @target_ids, $target_node->{'id'};
-              push @arrow_types, 'coindex';
+                push @target_ids,  $target_node->{'id'};
+                push @arrow_types, 'coindex';
             }
         }
     }
@@ -585,7 +637,7 @@ sub node_style_hook {
     # alignment
     if ( $self->show_alignment and my $links = $node->attr('alignment') ) {
         foreach my $link (@$links) {
-            if (exists $self->_displayed_nodes->{$link->{'counterpart.rf'}}) {
+            if ( exists $self->_displayed_nodes->{ $link->{'counterpart.rf'} } ) {
                 push @target_ids,  $link->{'counterpart.rf'};
                 push @arrow_types, 'alignment';
             }
@@ -684,11 +736,13 @@ sub toggle_clause_collapsing {
             }
         }
     }
+    return;
 }
 
 sub toggle_alignment {
     my $self = shift;
     $self->show_alignment( not $self->show_alignment );
+    return;
 }
 
 1;
@@ -703,7 +757,7 @@ Treex::Core::TredView - visualization of Treex files in TrEd
 
 =head1 VERSION
 
-version 0.07191
+version 0.08051
 
 =head1 DESCRIPTION
 
@@ -721,7 +775,7 @@ thickness) should be used for them.
 
 The TrEd visualization is precomputed statically after a file is loaded,
 therefore the extension can be currently used only for browsing, not for
-editting the treex files.
+editing the treex files.
 
 =head1 METHODS
 
