@@ -1,6 +1,6 @@
 package Treex::Core::TredView::Styles;
 {
-  $Treex::Core::TredView::Styles::VERSION = '0.07191';
+  $Treex::Core::TredView::Styles::VERSION = '0.08051';
 }
 
 use Moose;
@@ -144,7 +144,7 @@ sub _nnode_style {
 sub _pnode_style {
     my ( $self, $node ) = @_;
 
-    my $terminal = $node->get_pml_type_name eq 'p-terminal.type' ? 1 : 0;
+    my $terminal = $node->is_leaf;
 
     my $style = '#{Line-coords:n,n,n,p,p,p}';
     $style .= '#{nodeXSkip:4}#{nodeYSkip:0}#{NodeLabel-skipempty:1}';
@@ -271,7 +271,7 @@ Treex::Core::TredView::Styles - Styling of trees in Tred (how they look)
 
 =head1 VERSION
 
-version 0.07191
+version 0.08051
 
 =head1 DESCRIPTION
 
